@@ -22,6 +22,8 @@ class SnapshotNotfound:
 
 
 class SnapshotRecorder(ObjectProxy):  # pylint: disable=abstract-method
+    __wrapped__: Any
+
     def __init__(self, path: Path, fmt: Fmt, ctx: SnapshotContext, current: Any):
         super().__init__(current)
         self._self_path = path
@@ -33,6 +35,7 @@ class SnapshotRecorder(ObjectProxy):  # pylint: disable=abstract-method
             self._self_ctx.matching.add(self._self_path)
         else:
             self._self_ctx.differing[self._self_path] = self._self_fmt, other
+            self.__wrapped__ = other
         return True
 
 
