@@ -5,14 +5,14 @@ import os
 import shutil
 from dataclasses import dataclass, field
 from pathlib import Path
-from typing import Any, Dict, List, Set, Tuple
+from typing import Any, Dict, Iterable, List, Set, Tuple
 
 from _pytest.terminal import TerminalReporter
 from pytest import Session
 
 from .format import Fmt
 from .review import ReviewTool
-from .utils import is_ci, pluralize
+from .utils import is_ci, pluralize, remove_path, rename_path
 
 
 @dataclass
@@ -68,7 +68,7 @@ class SnapshotContext:
 
         if session.should_delete:
             for path in self.deleted:
-                path.unlink()
+                remove_path(path)
                 session.deleted.add(path)
 
         self.reset()
@@ -154,10 +154,10 @@ class SnapshotSession(Dict[Path, SnapshotContext]):
 
             for snapshot, destination in review_tool.collect():
                 if destination:
-                    snapshot.rename(destination)
+                    rename_path(snapshot, destination)
                     self.updated.add(destination)
                 else:
-                    snapshot.unlink()
+                    remove_path(snapshot)
                     self.rejected.add(snapshot)
                 self.recorded.discard(snapshot)
 
@@ -185,7 +185,7 @@ class SnapshotSession(Dict[Path, SnapshotContext]):
         self.tr.section("SNAPSHOTS", blue=True)
 
         for operation, snapshots in report.items():
-            for snapshot in snapshots:
+            for snapshot in sorted(snapshots):
                 self.tr.write_line(f"{operation} {snapshot}")
 
         if self.notices:
@@ -197,4 +197,15 @@ class SnapshotSession(Dict[Path, SnapshotContext]):
                 self.tr.write_line(notice)
 
     def count_snapshots_to_review(self) -> int:
-        return sum(len(entries[-1]) for entries in os.walk(self.record_dir))
+        return len(list(self.collect_snapshots_to_review()))
+
+    def collect_snapshots_to_review(self) -> Iterable[str]:
+        for _, dirs, files in os.walk(self.record_dir):
+            directory_snapshots = {
+                directory
+                for directory in dirs
+                if any(directory.endswith(extension) for extension in Fmt.registry)
+            }
+            dirs[:] = set(dirs) - directory_snapshots
+            yield from directory_snapshots
+            yield from files
